<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\x6f\162\144\120\162\x65\x73\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\x4e\157\144\x65\152\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\164\x61\x74\151\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\x50\171\164\x68\157\x6e"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\x53\x5f\x4d\x45\x54\110\x4f\x44" => ["\x76\x61\x6c\165\x65" => "\144\x69\x72\145\143\164", "\x72\141\x77" => false], "\127\x50\x5f\x44\105\102\x55\x47\137\x44\x49\x53\120\x4c\101\131" => ["\x76\141\x6c\x75\x65" => "\146\x61\x6c\163\x65", "\162\141\167" => true], "\127\x50\137\x44\x45\102\x55\107\x5f\x4c\117\107" => ["\166\141\x6c\165\145" => "\164\162\x75\x65", "\x72\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\120\137\x41\114\x4c\x4f\127\137\115\125\x4c\x54\111\123\111\124\105" => ["\166\141\x6c\x75\x65" => "\x74\162\x75\145", "\162\141\167" => true], "\115\x55\x4c\124\x49\123\111\x54\105" => ["\166\x61\154\x75\145" => "\x74\x72\165\x65", "\x72\x61\x77" => true], "\123\x55\x42\104\117\x4d\x41\111\x4e\x5f\111\x4e\123\x54\x41\114\x4c" => ["\x76\141\x6c\x75\x65" => "\146\141\x6c\x73\x65", "\x72\x61\167" => true], "\x44\x4f\x4d\x41\x49\116\x5f\103\x55\x52\x52\105\x4e\x54\x5f\123\x49\x54\105" => ["\x76\x61\x6c\165\x65" => '', "\162\x61\x77" => false], "\x50\101\x54\x48\137\x43\125\x52\122\105\116\x54\137\x53\111\124\x45" => ["\x76\x61\154\x75\x65" => "\57", "\162\x61\167" => false], "\123\111\124\x45\x5f\111\x44\137\103\x55\122\122\x45\x4e\x54\x5f\123\x49\x54\105" => ["\166\141\154\x75\x65" => 1, "\x72\141\167" => true], "\102\114\117\107\137\111\104\137\103\x55\122\122\x45\116\124\137\x53\111\124\x45" => ["\x76\x61\x6c\x75\145" => 1, "\x72\x61\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto C3784; e4b6d: $this->databaseServerEntityManager = $databaseServerEntityManager; goto C8bc4; Bed27: $this->validator = $validator; goto e42ee; C2a4f: $this->domainNameParser = $domainNameParser; goto Bed27; cd14d: $this->certificateEntityManager = $certificateEntityManager; goto cdffa; C3784: $this->configManager = $configManager; goto Dace3; E7f87: $this->databaseUserEntityManager = $databaseUserEntityManager; goto e4b6d; cdffa: $this->databaseEntityManager = $databaseEntityManager; goto E7f87; Dace3: $this->siteEntityManager = $siteEntityManager; goto cd14d; C8bc4: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto C2a4f; e42ee: parent::__construct($translator, $logger); goto d0152; d0152: } public function index(Request $request) : Response { goto F8505; F8505: $hasPermissions = $this->hasPermissions(); goto Be7db; Eff5f: return $response; goto fd14e; F9eb0: goto Abab3; goto Ed356; E4f5e: $response = $this->render("\106\x72\157\x6e\x74\x65\x6e\144\x2f\123\151\164\145\x2f\x4e\145\x77\x2f\151\x6e\x64\x65\170\x2e\x68\164\x6d\154\56\x74\x77\151\147", ["\165\x73\145\162" => $user]); goto e1b89; Be7db: if (true === $hasPermissions) { goto Df34f; } goto ed5cf; ed5cf: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\x73\151\164\145\163")); goto F9eb0; b7ec1: $user = $this->getUser(); goto E4f5e; e1b89: Abab3: goto Eff5f; Ed356: Df34f: goto b7ec1; fd14e: } public function newPythonSite(Request $request) : Response { goto cf258; f3305: C9825: goto a1746; Dc90d: ab4a9: goto f3305; E3df0: if (!(true === $request->isMethod("\x50\x4f\123\x54"))) { goto C9825; } goto E8dd8; d8c71: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\151\x74\x65\x73")); goto db109; B29d8: de9e8: goto Dc90d; cc8ca: return $response; goto E901d; Fed9c: e343e: goto cc8ca; B1e1c: if (!(false === is_null($response))) { goto de9e8; } goto ccdcb; E2c87: d051c: goto C9ffc; cf258: $hasPermissions = $this->hasPermissions(); goto D8f7d; db109: goto e343e; goto E2c87; D8f7d: if (true === $hasPermissions) { goto d051c; } goto d8c71; D0a81: $pythonSettings = new PythonSettingsEntity(); goto Fd130; a1746: $response = $this->render("\x46\162\x6f\x6e\x74\145\156\x64\57\123\151\164\x65\x2f\116\x65\x77\57\x70\x79\x74\x68\157\156\x2e\x68\164\x6d\x6c\56\x74\167\151\147", ["\165\x73\145\162" => $user, "\146\157\162\x6d" => $form->createView(), "\x66\157\x72\x6d\x45\162\x72\x6f\x72\x73" => $this->formErrors]); goto Fed9c; ccdcb: return $response; goto B29d8; Bb71e: if (!(true === $form->isSubmitted())) { goto ab4a9; } goto fa7a3; fa7a3: $response = $this->handleCreatePythonSiteForm($request, $form); goto B1e1c; Fd130: $form = $this->createPythonSiteForm($pythonSettings); goto E3df0; E8dd8: $form->handleRequest($request); goto Bb71e; C9ffc: $user = $this->getUser(); goto D0a81; E901d: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto df7c5; df7c5: $form = $this->createForm("\101\160\x70\x5c\106\157\162\x6d\134\x53\x69\164\x65\x4e\x65\167\x50\171\164\x68\x6f\156\124\171\160\145", $pythonSettings, ["\x61\x63\164\151\157\x6e" => $this->generateUrl("\x63\x6c\x70\137\163\151\164\x65\137\160\x79\164\150\157\x6e\x5f\x6e\145\167"), "\155\x65\x74\x68\x6f\144" => "\x50\117\x53\x54", "\141\164\x74\x72" => ["\151\x64" => "\156\145\167\55\160\x79\164\150\157\156\x2d\x73\x69\164\x65\x2d\x66\157\x72\155"]]); goto f0a71; f0a71: $form->add("\163\x75\142\x6d\x69\164", SubmitType::class, ["\141\x74\164\x72" => ["\x63\154\x61\163\163" => "\x62\x74\x6e\40\142\164\x6e\55\x6c\x67\x20\x62\x74\x6e\x2d\142\x6c\165\x65"], "\154\141\x62\145\154" => "\x43\162\145\x61\x74\145"]); goto B72a9; B72a9: return $form; goto e368b; e368b: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto c0adc; e2e32: $this->formErrors = $this->getErrorMessages($form); goto a8e4b; c0adc: if (true === $form->isValid()) { goto c0375; } goto e2e32; a8e4b: goto d5474; goto cc325; Ec513: d5474: goto Cb95d; b0970: try { goto ba8d0; C3ec1: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto C8f9f; c9fc6: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto aac8d; Af347: goto d828f; goto b0471; ba8d0: $session = $request->getSession(); goto D469b; C4f6c: $siteUser = $form->get("\163\151\x74\145\x55\163\x65\x72")->getData(); goto c0196; Ffc40: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\151\x74\x65\x73")); goto F9b75; bc4a6: $user = $this->getUser(); goto E0b61; E0b61: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto F6d9c; C8f9f: $session->getFlashBag()->set("\163\x75\x63\143\x65\163\163", $this->translator->trans("\123\151\x74\145\x20\x68\141\163\x20\142\x65\145\x6e\40\x63\162\x65\141\164\145\144\x2e")); goto Ffc40; b6067: $pythonVersion = $form->get("\160\x79\164\x68\157\156\x56\145\162\x73\x69\157\x6e")->getData(); goto d43de; F9b75: return $response; goto A6af5; aac8d: if (false === is_null($vhostTemplateEntity)) { goto efcad; } goto d8330; d43de: $port = $form->get("\160\157\162\x74")->getData(); goto C4f6c; b0471: efcad: goto bc4a6; fb287: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto c9fc6; c0196: $siteUserPassword = $form->get("\x73\151\x74\x65\x55\x73\x65\x72\x50\141\163\163\167\x6f\x72\x64")->getData(); goto fb287; d8330: throw new \Exception(sprintf("\x56\150\x6f\x73\164\40\x74\145\x6d\x70\154\141\164\145\40\x22\45\x73\x22\40\x6e\x6f\164\40\x66\x6f\165\x6e\x64\x2e", $vhostTemplateName)); goto Af347; D469b: $domainName = $form->get("\144\x6f\x6d\141\151\x6e\x4e\141\x6d\x65")->getData(); goto b6067; F6d9c: $eventData = ["\x73\x69\x74\x65" => $domainName, "\163\151\x74\145\125\163\x65\162" => $siteUser, "\x70\x79\164\150\x6f\x6e\126\x65\162\163\x69\x6f\x6e" => $pythonVersion, "\x70\x6f\162\164" => $port]; goto C3ec1; A6af5: d828f: goto a8539; a8539: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\145\162", $this->translator->trans("\101\156\40\145\162\162\x6f\162\x20\150\x61\163\40\157\x63\x63\x75\162\162\145\144\54\40\x65\162\162\x6f\x72\x20\155\x65\x73\x73\141\147\x65\x3a\40\45\145\162\x72\x6f\162\x4d\145\163\163\141\x67\145\x25", ["\45\145\162\x72\157\x72\x4d\x65\x73\163\x61\x67\x65\x25" => $e->getMessage()])); } goto Ec513; cc325: c0375: goto b0970; Cb95d: } public function newNodejsSite(Request $request) : Response { goto D7df8; F8a8c: $nodejsSettings = new NodejsSettingsEntity(); goto Dbd93; ff1d0: if (true === $hasPermissions) { goto Aa4a4; } goto df9d6; Fc626: Aa4a4: goto Fab1c; E0eff: A3b25: goto d0511; De445: goto A3b25; goto Fc626; e24ce: E6927: goto Fd05a; d6c7a: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto E6927; } goto de16f; A60ad: if (!(false === is_null($response))) { goto Cf1af; } goto E8433; de16f: $form->handleRequest($request); goto Fd0bc; Fd05a: $response = $this->render("\x46\162\x6f\156\x74\145\156\x64\57\123\x69\x74\x65\x2f\116\x65\167\x2f\156\157\x64\x65\152\x73\x2e\x68\164\155\154\56\x74\x77\x69\x67", ["\165\163\x65\x72" => $user, "\146\157\x72\x6d" => $form->createView(), "\146\x6f\162\x6d\105\x72\x72\x6f\162\163" => $this->formErrors]); goto E0eff; D0b6e: $response = $this->handleCreateNodejsSiteForm($request, $form); goto A60ad; Fd0bc: if (!(true === $form->isSubmitted())) { goto ca575; } goto D0b6e; Dbd93: $form = $this->createNodejsSiteForm($nodejsSettings); goto d6c7a; Fab1c: $user = $this->getUser(); goto F8a8c; d0511: return $response; goto C6ed3; df9d6: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\x69\164\x65\x73")); goto De445; D7df8: $hasPermissions = $this->hasPermissions(); goto ff1d0; E8433: return $response; goto F4d5e; Ac92b: ca575: goto e24ce; F4d5e: Cf1af: goto Ac92b; C6ed3: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto df367; D333e: $form->add("\x73\165\x62\155\x69\164", SubmitType::class, ["\141\x74\x74\x72" => ["\143\x6c\x61\163\x73" => "\x62\164\156\40\142\x74\x6e\x2d\154\x67\40\x62\x74\x6e\55\142\x6c\165\x65"], "\x6c\x61\142\x65\154" => "\103\162\145\x61\164\x65"]); goto ced74; df367: $form = $this->createForm("\x41\160\160\x5c\106\157\x72\x6d\134\x53\x69\x74\x65\116\145\167\x4e\157\144\x65\x6a\163\x54\171\160\x65", $nodejsSettings, ["\141\x63\x74\x69\x6f\156" => $this->generateUrl("\143\154\x70\x5f\x73\151\164\145\x5f\x6e\x6f\x64\x65\152\x73\x5f\x6e\x65\x77"), "\155\145\x74\x68\157\144" => "\x50\117\x53\x54", "\x61\x74\164\162" => ["\x69\144" => "\x6e\x65\x77\55\156\x6f\144\x65\x6a\163\x2d\x73\x69\x74\145\x2d\146\x6f\x72\155"]]); goto D333e; ced74: return $form; goto e99e8; e99e8: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto d2cbf; b8a82: $this->formErrors = $this->getErrorMessages($form); goto d5817; Ea214: Dd40b: goto d7f6d; d2cbf: if (true === $form->isValid()) { goto Dd40b; } goto b8a82; d5817: goto b5774; goto Ea214; d7f6d: try { goto Bb416; f207b: return $response; goto d73a1; D653a: if (false === is_null($vhostTemplateEntity)) { goto e46b0; } goto C1a76; ccea3: e46b0: goto F97e5; Bf761: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D653a; d73a1: e6228: goto Bc494; c3b53: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto cf448; d1e3c: $siteUserPassword = $form->get("\x73\x69\164\x65\x55\163\145\x72\x50\141\x73\163\x77\x6f\162\x64")->getData(); goto D835c; C1a76: throw new \Exception(sprintf("\126\x68\157\163\164\40\164\x65\155\160\x6c\x61\164\x65\x20\x22\x25\x73\42\40\156\157\164\x20\146\x6f\x75\156\144\56", $vhostTemplateName)); goto a4845; Ac87e: $domainName = $form->get("\144\157\155\141\151\x6e\x4e\141\155\145")->getData(); goto C24b8; A2e23: $session->getFlashBag()->set("\x73\x75\143\143\x65\163\x73", $this->translator->trans("\123\151\164\x65\x20\x68\141\163\40\142\145\x65\x6e\x20\143\162\x65\141\x74\x65\144\x2e")); goto a5950; C3cf8: $siteUser = $form->get("\x73\151\x74\145\125\163\x65\x72")->getData(); goto d1e3c; F97e5: $user = $this->getUser(); goto c3b53; Bb416: $session = $request->getSession(); goto Ac87e; C24b8: $nodejsVersion = $form->get("\x6e\x6f\144\x65\x6a\163\126\x65\162\x73\151\x6f\x6e")->getData(); goto C2567; Dc671: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto A2e23; a5950: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\164\x65\x73")); goto f207b; cf448: $eventData = ["\163\x69\x74\145" => $domainName, "\x73\151\164\x65\125\x73\145\162" => $siteUser, "\156\x6f\x64\145\152\163\x56\x65\162\x73\151\157\x6e" => $nodejsVersion, "\160\157\162\164" => $port]; goto Dc671; C2567: $port = $form->get("\x70\x6f\x72\164")->getData(); goto C3cf8; D835c: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto Bf761; a4845: goto e6228; goto ccea3; Bc494: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\147\145\x72", $this->translator->trans("\101\156\x20\x65\x72\162\157\x72\40\x68\x61\x73\40\x6f\143\x63\x75\162\162\x65\144\x2c\40\145\162\x72\157\x72\x20\x6d\x65\x73\163\141\x67\x65\x3a\x20\45\145\x72\x72\x6f\162\115\x65\x73\163\141\147\145\45", ["\x25\145\x72\x72\x6f\x72\115\x65\x73\163\141\147\x65\45" => $e->getMessage()])); } goto Ec1e4; Ec1e4: b5774: goto A6b30; A6b30: } public function newStaticSite(Request $request) : Response { goto C575b; C4c99: if (true === $hasPermissions) { goto ad23c; } goto C1cb7; e46ce: if (!(true === $form->isSubmitted())) { goto Ead0c; } goto a2769; Eb093: ad23c: goto C40ea; C575b: $hasPermissions = $this->hasPermissions(); goto C4c99; bbb01: Bc583: goto E273e; C40ea: $user = $this->getUser(); goto B7b80; E1969: if (!(false === is_null($response))) { goto b84c9; } goto B45f0; B45f0: return $response; goto df049; ae265: goto e8854; goto Eb093; a2769: $response = $this->handleCreateStaticSiteForm($request, $form); goto E1969; E273e: $response = $this->render("\x46\x72\x6f\156\x74\145\x6e\x64\57\123\x69\164\x65\x2f\x4e\145\x77\57\163\x74\x61\164\x69\143\x2e\150\x74\x6d\154\56\164\167\151\147", ["\x75\x73\145\162" => $user, "\x66\x6f\x72\155" => $form->createView(), "\146\x6f\162\155\105\x72\x72\x6f\x72\163" => $this->formErrors]); goto d08d2; df049: b84c9: goto df9a3; aa95d: $form->handleRequest($request); goto e46ce; df9a3: Ead0c: goto bbb01; d08d2: e8854: goto b6f90; b6f90: return $response; goto cf279; f83fc: if (!(true === $request->isMethod("\120\117\123\124"))) { goto Bc583; } goto aa95d; B7b80: $form = $this->createStaticSiteForm(); goto f83fc; C1cb7: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\151\x74\x65\x73")); goto ae265; cf279: } private function createStaticSiteForm() : Form { goto A7595; d8539: $form->add("\x73\165\x62\155\x69\164", SubmitType::class, ["\141\x74\x74\x72" => ["\143\x6c\141\x73\x73" => "\142\164\x6e\x20\x62\164\156\55\154\147\x20\142\164\156\x2d\x62\154\x75\145"], "\154\141\142\145\154" => "\x43\162\x65\x61\164\145"]); goto E6d0c; A7595: $form = $this->createForm("\101\x70\160\x5c\x46\157\x72\x6d\134\123\151\x74\x65\x4e\145\167\x53\x74\141\164\x69\x63\x54\171\x70\x65", [], ["\141\x63\x74\151\157\156" => $this->generateUrl("\x63\x6c\160\x5f\x73\151\x74\145\x5f\x73\x74\141\164\x69\143\137\156\145\x77"), "\x6d\145\x74\150\157\x64" => "\120\117\123\124", "\141\164\x74\x72" => []]); goto d8539; E6d0c: return $form; goto Dc6ac; Dc6ac: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto E18af; Ca9f0: try { goto F5df3; D1053: goto f5154; goto a4ebd; afab1: return $response; goto ffe21; Edc3f: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto a5467; F5df3: $session = $request->getSession(); goto Dcd26; Cca66: if (false === is_null($vhostTemplateEntity)) { goto Ee388; } goto Eb21e; Efa31: $eventData = ["\163\151\x74\x65" => $domainName, "\x73\151\164\145\x55\163\x65\x72" => $siteUser]; goto F40ea; c81aa: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto Efa31; Acf0f: $siteUser = $form->get("\163\x69\x74\x65\x55\x73\x65\x72")->getData(); goto Aa3cc; F40ea: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto ec0a9; ec0a9: $session->getFlashBag()->set("\163\165\x63\143\145\x73\x73", $this->translator->trans("\x53\x69\x74\145\40\150\x61\x73\x20\x62\145\x65\156\40\x63\162\145\x61\x74\x65\x64\x2e")); goto ca0a1; Eb21e: throw new \Exception(sprintf("\x56\150\x6f\x73\164\40\x74\x65\x6d\x70\x6c\x61\164\x65\x20\42\45\163\x22\40\156\x6f\x74\x20\x66\x6f\x75\x6e\144\56", $vhostTemplateName)); goto D1053; ffe21: f5154: goto c382d; a5467: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Cca66; Dcd26: $domainName = $form->get("\144\157\x6d\x61\x69\x6e\x4e\141\x6d\x65")->getData(); goto Acf0f; ca0a1: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\x69\x74\145\163")); goto afab1; a4ebd: Ee388: goto C59e3; C59e3: $user = $this->getUser(); goto c81aa; Aa3cc: $siteUserPassword = $form->get("\x73\151\x74\x65\x55\163\145\x72\x50\141\x73\x73\x77\x6f\x72\144")->getData(); goto Edc3f; c382d: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\x65\x72", $this->translator->trans("\101\x6e\40\x65\x72\162\157\162\40\x68\x61\163\40\x6f\143\143\165\162\162\145\x64\x2c\40\145\x72\162\x6f\162\x20\155\145\x73\x73\x61\147\145\72\40\45\145\x72\162\x6f\x72\115\x65\163\x73\141\x67\145\x25", ["\45\x65\162\162\x6f\162\115\145\163\163\141\x67\x65\45" => $e->getMessage()])); } goto e4b4d; c4daa: $this->formErrors = $this->getErrorMessages($form); goto c6ba7; e4b4d: d93eb: goto Cebb7; c6ba7: goto d93eb; goto d18aa; E18af: if (true === $form->isValid()) { goto b0e95; } goto c4daa; d18aa: b0e95: goto Ca9f0; Cebb7: } public function newPhpSite(Request $request) : Response { goto A9a47; d6b34: $response = $this->render("\106\162\x6f\x6e\164\145\156\144\57\x53\x69\x74\145\x2f\x4e\145\167\x2f\x70\x68\x70\x2e\x68\x74\155\x6c\56\164\167\151\x67", ["\165\x73\145\162" => $user, "\x66\x6f\162\x6d" => $form->createView(), "\x66\157\x72\x6d\105\x72\x72\x6f\162\x73" => $this->formErrors]); goto B01e0; b842e: $form = $this->createPhpSiteForm(); goto cce2c; D2e18: Cbe44: goto b083a; fd542: return $response; goto D2e18; be6c5: if (!(false === is_null($response))) { goto Cbe44; } goto fd542; Fc89a: goto aea41; goto eeadf; A7e2c: if (!(true === $form->isSubmitted())) { goto A67c7; } goto a5396; f8425: Cc729: goto d6b34; b083a: A67c7: goto f8425; cacc4: return $response; goto E8614; A9a47: $hasPermissions = $this->hasPermissions(); goto b5a76; ede7d: $form->handleRequest($request); goto A7e2c; eeadf: D4a00: goto C8792; a5396: $response = $this->handleCreatePhpSiteForm($request, $form); goto be6c5; B01e0: aea41: goto cacc4; D5dd6: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\x69\x74\x65\x73")); goto Fc89a; cce2c: if (!(true === $request->isMethod("\x50\117\123\x54"))) { goto Cc729; } goto ede7d; C8792: $user = $this->getUser(); goto b842e; b5a76: if (true === $hasPermissions) { goto D4a00; } goto D5dd6; E8614: } private function createPhpSiteForm() : Form { goto B292b; B292b: $form = $this->createForm("\x41\160\x70\134\106\x6f\162\x6d\x5c\123\x69\164\x65\x4e\145\167\120\x68\160\x54\x79\160\145", [], ["\141\143\164\151\x6f\x6e" => $this->generateUrl("\143\154\x70\137\x73\x69\x74\145\137\x70\150\x70\x5f\156\145\167"), "\x6d\145\x74\150\x6f\x64" => "\x50\x4f\x53\124", "\141\164\x74\162" => []]); goto C5739; F00f2: return $form; goto d3c89; C5739: $form->add("\163\x75\142\155\151\164", SubmitType::class, ["\x61\164\x74\x72" => ["\143\x6c\141\163\163" => "\x62\164\156\40\x62\164\156\x2d\x6c\147\x20\x62\164\156\x2d\142\x6c\x75\145"], "\154\x61\142\145\x6c" => "\x43\162\x65\x61\164\x65"]); goto F00f2; d3c89: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto f4af6; b842f: B0c19: goto D33f0; D33f0: try { goto E611f; A7692: $session->getFlashBag()->set("\163\x75\143\143\x65\163\163", $this->translator->trans("\123\x69\x74\145\x20\x68\141\163\40\x62\x65\x65\x6e\40\143\x72\x65\141\164\x65\144\56")); goto E207f; dd658: Dc477: goto F436c; c1abc: $eventData = ["\163\x69\164\x65" => $domainName, "\166\150\157\163\164\124\x65\155\160\154\141\x74\x65\116\x61\x6d\145" => $vhostTemplateName, "\160\150\160\x56\x65\162\x73\151\157\156" => $phpVersion, "\163\x69\164\x65\125\163\145\x72" => $siteUser]; goto B923d; fb996: $domainName = $form->get("\x64\x6f\x6d\141\151\x6e\x4e\x61\155\145")->getData(); goto fb800; B923d: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto A7692; fb800: $phpVersion = $form->get("\160\x68\x70\x56\145\162\x73\x69\157\156")->getData(); goto Ef3c1; d3124: $rootDirectory = sprintf("\x25\163\x2f\45\x73", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\57"), "\57")); goto dd658; Eec41: throw new \Exception(sprintf("\x56\x68\157\x73\x74\x20\164\x65\155\x70\x6c\x61\x74\145\40\42\45\x73\42\40\x6e\157\164\x20\x66\x6f\165\156\144\x2e", $vhostTemplateName)); goto d8a4c; d8a4c: goto d106e; goto fba67; E6f49: if (false === is_null($vhostTemplateEntity)) { goto ebdf5; } goto Eec41; Ef3c1: $siteUser = $form->get("\163\x69\164\145\125\163\x65\x72")->getData(); goto D4c45; E611f: $session = $request->getSession(); goto E378c; B23e9: return $response; goto F4f24; E378c: $vhostTemplateName = $form->get("\141\x70\x70\154\151\143\141\x74\151\x6f\156")->getData(); goto fb996; F436c: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword); goto c1abc; Ec319: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto Dc477; } goto d3124; F4f24: d106e: goto A97cd; Ac671: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto E6f49; E207f: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\x73\151\x74\x65\x73")); goto B23e9; D4c45: $siteUserPassword = $form->get("\163\151\164\x65\x55\x73\145\x72\120\141\x73\163\x77\x6f\x72\x64")->getData(); goto Ac671; f9833: $rootDirectory = $domainName; goto Ec319; F9008: $user = $this->getUser(); goto f9833; fba67: ebdf5: goto F9008; A97cd: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\145\162", $this->translator->trans("\x41\156\x20\x65\162\x72\157\162\40\150\x61\x73\40\157\x63\x63\165\162\x72\x65\144\54\40\145\x72\x72\157\162\40\155\145\x73\x73\x61\x67\x65\x3a\x20\x25\x65\162\x72\157\x72\115\145\x73\x73\141\x67\145\45", ["\x25\145\x72\x72\x6f\x72\115\145\x73\163\x61\x67\145\45" => $e->getMessage()])); } goto ac086; f4af6: if (true === $form->isValid()) { goto B0c19; } goto C6163; C6163: $this->formErrors = $this->getErrorMessages($form); goto acb2a; ac086: e6d21: goto Cd4f1; acb2a: goto e6d21; goto b842f; Cd4f1: } public function newWordPressSite(Request $request) : Response { goto c10c1; Ba85e: if (true === $hasPermissions) { goto f9c94; } goto E16f8; Bd174: fdb5b: goto b9e93; Bf0ef: $response = $this->render("\x46\162\x6f\x6e\x74\x65\x6e\x64\x2f\123\151\x74\145\57\x4e\145\167\x2f\167\157\162\144\x70\x72\x65\x73\163\x2e\x68\x74\x6d\154\56\x74\x77\151\147", ["\165\163\x65\162" => $user, "\146\x6f\162\155" => $form->createView(), "\x66\x6f\x72\x6d\105\x72\x72\x6f\162\163" => $this->formErrors, "\160\162\x65\111\x6e\163\164\141\x6c\154" => $preInstall]); goto E5b47; Aa36d: C4b45: goto Bf0ef; c10c1: $hasPermissions = $this->hasPermissions(); goto Ba85e; d287e: return $response; goto Ff4c7; C00c0: if (!(true === $form->isSubmitted())) { goto aa520; } goto c06fe; b9e93: aa520: goto Aa36d; Fa40f: $form = $this->createWordPressSiteForm(); goto D5798; A36d0: return $response; goto Bd174; ad919: f9c94: goto E40b6; E40b6: $user = $this->getUser(); goto Fa40f; E0b99: goto Dcb2c; goto ad919; E5b47: Dcb2c: goto d287e; D5798: $preInstall = true; goto Baec4; F4b4e: if (!(false === is_null($response))) { goto fdb5b; } goto A36d0; Baec4: if (!(true === $request->isMethod("\x50\x4f\x53\x54"))) { goto C4b45; } goto D1089; D1089: $form->handleRequest($request); goto C00c0; Aff0b: $response = $this->handleCreateWordPressSiteForm($request, $form); goto F4b4e; c06fe: $preInstall = $form->get("\x70\x72\145\x49\156\x73\x74\x61\x6c\154")->getData(); goto Aff0b; E16f8: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\151\164\x65\163")); goto E0b99; Ff4c7: } private function createWordPressSiteForm() : Form { goto ae76e; f36dc: return $form; goto Efaf4; B10af: $form->add("\163\165\x62\x6d\x69\x74", SubmitType::class, ["\x61\x74\164\x72" => ["\x63\154\141\163\x73" => "\142\x74\156\x20\x62\x74\x6e\x2d\154\147\x20\x62\164\156\55\142\x6c\165\145"], "\154\x61\x62\x65\154" => "\103\162\x65\141\x74\x65"]); goto f36dc; ae76e: $form = $this->createForm("\101\x70\x70\x5c\x46\x6f\162\x6d\x5c\123\151\x74\x65\x4e\x65\167\127\157\162\x64\x50\x72\145\x73\163\x54\171\x70\x65", [], ["\141\143\x74\151\x6f\156" => $this->generateUrl("\143\154\x70\x5f\x73\x69\164\x65\x5f\167\x6f\x72\144\x70\162\145\x73\163\137\x6e\145\167"), "\x6d\145\164\x68\x6f\144" => "\120\x4f\123\x54", "\x61\x74\x74\162" => ["\151\144" => "\156\145\x77\55\167\x6f\x72\x64\160\x72\x65\163\x73\55\163\x69\x74\x65\55\146\x6f\162\155"]]); goto B10af; Efaf4: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto F1729; C4117: try { goto E3dc7; aaf71: $preInstall = $form->get("\x70\x72\x65\x49\156\x73\164\x61\x6c\x6c")->getData(); goto ffff4; e8624: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto f58e3; a3de7: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto B1635; Ffef9: $instance = $request->attributes->get("\x69\156\x73\x74\141\156\x63\145"); goto e0cc2; f58e3: $siteCredentials["\x44\141\x74\141\x62\x61\x73\145"] = ["\x48\x6f\163\x74" => $activeDatabaseServerEntity->getHost(), "\120\157\x72\x74" => $activeDatabaseServerEntity->getPort(), "\x44\x61\x74\x61\142\x61\163\x65\40\116\141\x6d\x65" => $databaseName, "\x44\x61\164\x61\x62\x61\x73\x65\x20\x55\163\x65\x72\40\x4e\141\x6d\x65" => $databaseUserName, "\x44\141\164\141\x62\x61\163\x65\40\x55\x73\145\x72\x20\x50\x61\163\163\x77\157\162\144" => $databaseUserPassword]; goto db9ef; e87a7: $adminPassword = $form->get("\141\144\x6d\x69\156\x50\141\163\163\167\x6f\162\144")->getData(); goto A3af9; C0d0f: $databaseEntity = $this->databaseEntityManager->createEntity(); goto Ce98f; Bc878: $databaseUserEntity->setDatabase($databaseEntity); goto B2e44; a4d1a: $databaseName = $this->getUniqueDatabaseName($generatedName); goto aebe0; afcec: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Ffef9; d427b: $isMultiSite = $form->get("\155\x75\x6c\x74\x69\x53\151\x74\145")->getData(); goto f8324; A3af9: $adminEmail = $form->get("\x61\x64\x6d\151\156\x45\x6d\x61\151\x6c")->getData(); goto d427b; ffff4: $generatedName = $this->generateNameFromDomainName($domainName); goto efab2; d34c4: $siteUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto A0fee; A0fee: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto b4860; c85f3: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto B2381; Bfe48: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\151\x74\145\137\x77\157\162\144\160\162\145\x73\163\x5f\151\x6e\163\164\x61\x6c\x6c\x65\144")); goto Bba71; b527c: $adminUserName = $form->get("\141\x64\x6d\151\156\125\163\145\x72\116\x61\x6d\x65")->getData(); goto e87a7; B1635: $url = sprintf("\150\164\x74\160\163\x3a\57\x2f\x25\163", $siteEntity->getDomainName()); goto b7c50; E6fe6: $databaseManager->createDatabase($databaseEntity); goto Cfc68; Ad946: $session->set("\x73\151\x74\x65\x43\x72\145\144\145\156\164\151\x61\154\163", $siteCredentials); goto F90f2; E3dc7: $user = $this->getUser(); goto F9ae0; db9ef: $siteCredentials["\x57\157\162\x64\x50\x72\145\163\163"] = ["\x41\x64\x6d\151\x6e\x20\105\x2d\x4d\141\x69\x6c" => $adminEmail, "\101\x64\x6d\x69\x6e\x20\125\163\145\162\40\x4e\x61\155\x65" => $adminUserName, "\x41\x64\155\x69\156\40\120\141\x73\x73\167\x6f\x72\x64" => $adminPassword, "\x41\x64\x6d\151\x6e\40\x55\x72\154" => sprintf("\x68\x74\x74\160\x73\x3a\x2f\57\45\x73\x2f\167\160\55\x61\144\x6d\x69\156\x2f", rtrim($domainName, "\57"))]; goto f9214; Cfc68: $databaseManager->createUser($databaseUserEntity); goto ddee1; efab2: $siteUser = $this->getUniqueSiteUserName($generatedName); goto d34c4; F2289: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto Bfe48; f3602: $domainName = $form->get("\x64\x6f\155\x61\151\156\x4e\x61\x6d\145")->getData(); goto aaf71; e0cc2: $siteCredentials = ["\x53\x69\164\145" => ["\x49\x50" => $instance->getIpv4PublicIp(), "\104\157\x6d\141\151\x6e\40\x4e\x61\x6d\145" => sprintf("\x68\164\164\160\163\x3a\57\57\x25\163", $domainName), "\x53\151\164\145\x20\x55\x73\145\x72" => $siteUser, "\x53\x69\164\x65\x20\x50\141\x73\x73\x77\x6f\x72\144" => $siteUserPassword]]; goto ac23b; B1ab4: $siteEntity->addDatabase($databaseEntity); goto B02c6; ddee1: $this->siteEntityManager->updateEntity($siteEntity); goto e8624; f9214: D6d8a: goto Ad946; e7910: $databaseEntity->setName($databaseName); goto D3534; b7c50: $title = $form->get("\x73\151\x74\145\x54\x69\164\x6c\x65")->getData(); goto b527c; F9ae0: $session = $request->getSession(); goto f3602; B02c6: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto E6fe6; f8324: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto C0d0f; F90f2: $eventData = ["\x73\151\164\145" => $domainName, "\163\x69\164\145\x55\163\x65\162" => $siteUser]; goto F2289; Ce98f: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto e7910; ac23b: if (!(true === $preInstall && false === is_null($siteEntity))) { goto D6d8a; } goto a4d1a; B2381: $databaseUserEntity->setUserName($databaseUserName); goto F7d1e; D3534: $databaseEntity->setSite($siteEntity); goto c85f3; F7d1e: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto Da9f9; aebe0: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto a3de7; fb7ee: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword); goto afcec; b4860: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto fb7ee; Bba71: return $response; goto B87f3; Da9f9: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto Bc878; B2e44: $databaseEntity->addUser($databaseUserEntity); goto B1ab4; B87f3: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\x67\145\162", $this->translator->trans("\x41\x6e\x20\145\162\x72\x6f\x72\40\x68\141\x73\x20\x6f\143\x63\165\162\x72\x65\144\54\x20\x65\162\162\x6f\162\40\155\x65\x73\163\141\147\x65\x3a\x20\45\x65\x72\x72\x6f\162\x4d\145\x73\163\x61\x67\145\x25", ["\x25\145\162\162\157\x72\x4d\x65\x73\x73\141\x67\145\45" => $e->getMessage()])); } goto ee766; b67d5: ca7a3: goto C4117; f53b6: goto E1575; goto b67d5; F1729: if (true === $form->isValid()) { goto ca7a3; } goto Ebd16; Ebd16: $this->formErrors = $this->getErrorMessages($form); goto f53b6; ee766: E1575: goto Ae066; Ae066: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto c6322; ec791: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto e1418; df3ac: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\154\165\x65"], $config["\x72\141\x77"]); A8870: } goto eedf2; B605f: $databaseName = $databaseEntity->getName(); goto a035a; Aaa58: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto ec791; cf605: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto f87ec; e1418: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\154\165\x65"], $config["\162\141\167"]); cd7be: } goto B8698; Ac575: a97fd: goto F5f01; B8698: E0033: goto ee265; a035a: $databaseUserName = $databaseUserEntity->getUserName(); goto cf605; d5e5f: $wordPressInstaller->downloadAndExtractLatestVersion(); goto Aaa58; c3389: $this->wordPressMultiSiteConfigValues["\104\117\115\x41\111\116\137\103\x55\x52\x52\105\x4e\124\x5f\123\111\124\x45"]["\166\x61\154\165\x65"] = $siteEntity->getDomainName(); goto df3ac; f87ec: $wordPressInstaller = new WordPressInstaller($siteEntity); goto d5e5f; c6322: $databaseHost = $databaseServerEntity->getHost(); goto B605f; F5f01: $wordPressInstaller->resetPermissions(); goto f4122; eedf2: E328c: goto Ac575; ee265: if (!(true === $isMultiSite)) { goto a97fd; } goto c3389; f4122: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword) : SiteEntity { goto e71e5; Ebcb0: $vhostTemplate = sprintf("\x25\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto be28f; Ff893: $phpSiteCreator->reloadPhpFpmService(); goto c6a35; c9733: $certificateEntity->setCertificate($selfSignedCertificate); goto bb815; cbb92: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E0527; c4713: $siteEntity->setUser($siteUser); goto B374c; E39b5: $phpSite->setPhpSettings($phpSettingsEntity); goto f9644; f9644: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto bdedf; be28f: A23b4: goto e0e30; B4cd6: $phpSite->setRegistrableDomain($registrableDomain); goto C1101; A74b1: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto edd87; } goto d2d51; bd9db: $phpSite->setCertificate($certificateEntity); goto E39b5; ecd09: cde3d: goto cfdd3; e71e5: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\x2f"); goto d3841; d00f0: $phpSiteCreator->createLogrotateFile(); goto f44d7; b98f2: $vhostTemplate->build(); goto E6fee; f358c: $siteEntity->setVhostTemplate($vhostTemplate); goto a0707; f2918: $subdomain = $resolvedDomainName->subDomain()->toString(); goto E8118; f0c28: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto A4638; cecf2: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto bd9db; E5d04: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto c9733; b2ac5: $phpSiteCreator->reloadNginxService(); goto E5a6f; E7212: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Ba702; eb246: $siteEntity->setRootDirectory($rootDirectory); goto c7dc8; Beaa7: $siteEntity->setType(SiteEntity::TYPE_PHP); goto cf15e; c12f6: bcbad: goto De129; A1310: $vhostTemplate->resetProcessors(); goto f0c28; De129: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E69f7; E4f48: $phpSettingsEntity->setPhpVersion($phpVersion); goto Bddfa; ef2c3: $rsaKeyGenerator = new RsaKeyGenerator(); goto B23a9; Bddfa: $phpSettingsEntity->setSite($siteEntity); goto b7bcf; Acbf4: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto f2918; E8118: $subdomain = false === empty($subdomain) ? $subdomain : null; goto B1561; F8e3c: $certificateEntity->setSite($siteEntity); goto ef2c3; b7bcf: $siteConstraints = $this->validator->validate($siteEntity); goto d324a; B5c9d: $phpSite->setUser($siteEntity->getUser()); goto Fddf4; e60f1: if (!(true === is_null($subdomain))) { goto cde3d; } goto a4676; c5ccc: $phpSite->setDomainName($domainName); goto B4cd6; D4281: $phpSiteCreator->createRootDirectory(); goto d00f0; Ef4a2: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\56\x2f\56\x2e\57\x72\145\163\x6f\165\x72\x63\x65\x73\57\x6e\x67\x69\x6e\170\x2f\x76\x68\x6f\x73\164\137\164\145\155\x70\x6c\141\164\145\x2f\162\145\144\x69\x72\x65\143\164"); goto C132c; b65ed: if (!(false === empty($redirectionVhostTemplate))) { goto A23b4; } goto Ebcb0; c8ca3: $csr = $csrGenerator->generate(); goto E7212; Ab2a8: $siteEntity->setPhpSettings($phpSettingsEntity); goto E4f48; d12e5: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto b9346; Cba4c: $constraintViolationList->addAll($phpSettingsConstraints); goto c451f; d3841: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Acbf4; A3804: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto A1310; B10d6: return $siteEntity; goto Fb5e5; d992f: $constraintViolationList->addAll($siteConstraints); goto Cba4c; a0707: $phpSettingsEntity = new PhpSettingsEntity(); goto Ab2a8; bfb26: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto b98f2; Ba702: $certificateEntity->setDefaultCertificate(true); goto d12e5; E86f0: $phpSite = new PhpSite(); goto B5c9d; Fddf4: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto c5ccc; A4638: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto bfb26; Ba15a: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F8e3c; F26f3: $subjectAlternativeNames = []; goto e60f1; C1101: $phpSite->setSubdomain($subdomain); goto cecf2; F2d34: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ece07; d324a: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto A74b1; bb815: $siteEntity->setCertificate($certificateEntity); goto E86f0; b9346: $certificateEntity->setCsr($csr); goto E5d04; deacb: $vhostTemplate = new PhpVhostTemplate($phpSite); goto A3804; E0527: $this->siteEntityManager->updateEntity($siteEntity); goto B10d6; d2d51: $constraintViolationList = new ConstraintViolationList(); goto d992f; a95e8: $phpSiteCreator->createPrivateKeyAndCertificate(); goto ee603; cf15e: $siteEntity->setDomainName($domainName); goto c4713; d22de: $phpSiteCreator->createUser(); goto D4281; cfdd3: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto bcbad; } goto Ce26d; c7dc8: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto E4b9d; } goto Ef4a2; e0e30: E4b9d: goto f358c; D38c4: edd87: goto Ba15a; a4676: $subjectAlternativeNames[] = sprintf("\167\167\167\56\45\x73", $domainName); goto ecd09; f44d7: $phpSiteCreator->createIndexPhp(); goto a95e8; C1633: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto D38c4; B23a9: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F26f3; Ce26d: $subjectAlternativeNames[] = $registrableDomain; goto c12f6; E6fee: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto cbb92; E5a6f: $phpSiteCreator->resetPermissions(); goto deacb; ee603: $phpSiteCreator->createPhpFpmPool(); goto Ff893; C132c: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto b65ed; c451f: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto C1633; E69f7: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto c8ca3; bdedf: $phpSiteCreator = new PhpSiteCreator($phpSite); goto d22de; c6a35: $phpSiteCreator->createNginxVhost(); goto b2ac5; ece07: $siteEntity = $this->siteEntityManager->createEntity(); goto Beaa7; B374c: $siteEntity->setUserPassword($siteUserPassword); goto eb246; B1561: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto F2d34; Fb5e5: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto a2984; Eee54: $siteEntity->setVhostTemplate($vhostTemplate); goto acddd; F586c: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F1340; f4872: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto F1e73; d0cc2: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto B6790; E6094: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto Ff8f9; } goto Bde39; d41aa: $certificateEntity->setDefaultCertificate(true); goto c5b85; Dd9b9: $nodejsSite->setRegistrableDomain($registrableDomain); goto d8573; Ccdc6: throw new \Exception(implode("\73\40", $errorMessages)); goto dec1e; d380c: Ff8f9: goto Eee54; dec1e: Ae2a3: goto Ab87e; B1f3d: $subjectAlternativeNames[] = $registrableDomain; goto c3f4e; d8139: $nodejsSite->setUser($siteEntity->getUser()); goto a7411; c5b85: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C014f; d516e: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto f78c7; c564a: $nodejsSiteCreator->reloadNginxService(); goto F2fc7; F2fc7: $nodejsSiteCreator->resetPermissions(); goto B9226; Ed738: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto e8706; A6981: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Bab3a; C6609: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto d5dd4; a2984: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F6dc6; C21cb: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto C3f7c; B9226: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto b235b; d20a4: $nodejsSiteCreator->createNginxVhost(); goto c564a; e4b7d: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto d3722; afddc: $nodejsSite->setDomainName($domainName); goto Dd9b9; e723d: $nodejsSite = new NodejsSite(); goto d8139; a517a: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto d143e; b235b: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto a5965; e2afa: $nodejsSiteCreator->installNodejs(); goto fdcf0; Fbd70: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto B3ef7; d31fe: $constraintViolationList->addAll($nodejsSettingsConstraints); goto fca2c; B7cee: $rsaKeyGenerator = new RsaKeyGenerator(); goto F586c; d5744: $subdomain = false === empty($subdomain) ? $subdomain : null; goto d516e; C014f: $certificateEntity->setCsr($csr); goto e4b7d; d143e: $nodejsSite->setCertificate($certificateEntity); goto C666a; d1fb1: $nodejsSiteCreator->createLogrotateFile(); goto D041d; B3ef7: $csr = $csrGenerator->generate(); goto D1543; e4a27: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C4217; Bab3a: if (!(false === empty($redirectionVhostTemplate))) { goto a5e1a; } goto A1bed; C3f7c: $vhostTemplate->build(); goto e4a27; b9297: $subdomain = $resolvedDomainName->subDomain()->toString(); goto d5744; fdcf0: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto d20a4; acddd: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto ac0d6; d6cef: a3604: goto C376f; D3fc6: a5e1a: goto d380c; ac0d6: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto C6609; E23d5: $siteEntity->setCertificate($certificateEntity); goto e723d; A15d4: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Ed738; aeb2f: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Ae2a3; } goto db9b4; f78c7: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Ab2b9; a622d: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\56\x25\x73", $domainName); goto d6cef; d8573: $nodejsSite->setSubdomain($subdomain); goto a517a; Dc3ad: return $siteEntity; goto b7136; a5965: $vhostTemplate->resetProcessors(); goto f4872; c0623: $siteEntity->setRootDirectory($domainName); goto E6094; B6790: $siteEntity->setDomainName($domainName); goto Bc3a9; D1543: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto d41aa; e8706: $nodejsSiteCreator->createUser(); goto C1831; A7ca9: $siteConstraints = $this->validator->validate($siteEntity); goto F6ffe; B2454: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Fbd70; C666a: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto A15d4; A801b: $nodejsSettingsEntity->setSite($siteEntity); goto A7ca9; Bde39: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\x2e\57\x2e\x2e\57\162\145\163\157\x75\x72\143\145\x73\x2f\156\147\x69\x6e\x78\57\166\150\x6f\x73\164\x5f\x74\x65\x6d\160\154\141\x74\x65\x2f\x72\145\x64\151\162\x65\x63\164"); goto A6981; F6dc6: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b9297; fca2c: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Ccdc6; db9b4: $constraintViolationList = new ConstraintViolationList(); goto ec5a8; a7411: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto afddc; d5dd4: $nodejsSettingsEntity->setPort($port); goto A801b; C376f: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto Eb891; } goto B1f3d; c3f4e: Eb891: goto B2454; F6ffe: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto aeb2f; C1831: $nodejsSiteCreator->createRootDirectory(); goto d1fb1; C3d35: $this->siteEntityManager->updateEntity($siteEntity); goto Dc3ad; ec5a8: $constraintViolationList->addAll($siteConstraints); goto d31fe; D041d: $nodejsSiteCreator->createNvmDirectory(); goto e2afa; B6378: $certificateEntity->setSite($siteEntity); goto B7cee; d1281: if (!(true === is_null($subdomain))) { goto a3604; } goto a622d; F1340: $subjectAlternativeNames = []; goto d1281; Ab87e: $certificateEntity = $this->certificateEntityManager->createEntity(); goto B6378; d3722: $certificateEntity->setCertificate($selfSignedCertificate); goto E23d5; A1bed: $vhostTemplate = sprintf("\x25\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto D3fc6; c776e: $siteEntity->setUserPassword($siteUserPassword); goto c0623; F1e73: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto C21cb; Ab2b9: $siteEntity = $this->siteEntityManager->createEntity(); goto d0cc2; C4217: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto C3d35; Bc3a9: $siteEntity->setUser($siteUser); goto c776e; b7136: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto e7ec6; B79f3: $certificateEntity->setSite($siteEntity); goto Db803; e2299: $pythonSite->setRegistrableDomain($registrableDomain); goto ae9ae; D467e: $pythonSiteCreator->createRootDirectory(); goto e9035; Dbc00: $pythonSiteCreator->resetPermissions(); goto f8f98; a9a7e: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto e0b0e; a16b6: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto A23dc; caf0a: $this->siteEntityManager->updateEntity($siteEntity); goto f2276; a7d84: if (!(true === is_null($subdomain))) { goto E1dce; } goto d371c; cf6f4: $subdomain = false === empty($subdomain) ? $subdomain : null; goto e910f; b2cf6: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Cf66d; F456e: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto cc5eb; f9478: $pythonSiteCreator->reloadNginxService(); goto Dbc00; F3519: $siteEntity->setVhostTemplate($vhostTemplate); goto b4431; b3072: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto F0a88; Db803: $rsaKeyGenerator = new RsaKeyGenerator(); goto D08f7; e05a3: $siteEntity->setDomainName($domainName); goto D3adc; b445b: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Cf0ac; b5606: $pythonSettingsEntity->setSite($siteEntity); goto fa705; aa607: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Fac6d; a479a: $pythonSiteCreator->createNginxVhost(); goto f9478; fa705: $siteConstraints = $this->validator->validate($siteEntity); goto a65aa; e910f: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto f885c; Cf66d: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Dcd15; Ebc44: $pythonSiteCreator->writePythonVersionFile(); goto A387d; D3cb5: $certificateEntity->setCertificate($selfSignedCertificate); goto D3207; e147e: return $siteEntity; goto C895f; D08f7: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto A85f0; a65aa: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto Da681; B7165: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto eec5f; } goto F61af; Ee316: $constraintViolationList->addAll($siteConstraints); goto f71d2; f0116: $pythonSite->setDomainName($domainName); goto e2299; da0ac: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto fc1c8; F0a88: $pythonSite->setCertificate($certificateEntity); goto B4ecd; ad298: $subdomain = $resolvedDomainName->subDomain()->toString(); goto cf6f4; Da681: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto A5081; } goto ad073; e5f14: eec5f: goto b2cf6; A23dc: cd0f2: goto ee90e; db2e7: A5081: goto b46a4; b337a: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto e05a3; A387d: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto a479a; F8bd9: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto F44d6; E1f81: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto D3cb5; b4431: $pythonSettingsEntity = new PythonSettingsEntity(); goto Ed5cf; fcc7b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\x2e\x2f\x2e\56\57\x72\x65\163\x6f\x75\x72\143\x65\163\57\x6e\147\x69\156\x78\57\x76\150\x6f\163\164\x5f\164\145\155\160\x6c\141\x74\145\x2f\x72\145\144\151\x72\145\x63\x74"); goto ccb27; F61af: $subjectAlternativeNames[] = $registrableDomain; goto e5f14; cc5eb: $certificateEntity->setDefaultCertificate(true); goto d3a8e; D4e28: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto ad298; F44d6: $pythonSettingsEntity->setPort($port); goto b5606; A85f0: $subjectAlternativeNames = []; goto a7d84; e81f0: $siteEntity = $this->siteEntityManager->createEntity(); goto b337a; d371c: $subjectAlternativeNames[] = sprintf("\x77\167\x77\x2e\45\163", $domainName); goto a4f9d; fc1c8: $pythonSiteCreator->createUser(); goto D467e; a799a: $pythonSite->setUser($siteEntity->getUser()); goto d5928; d51d2: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto da0ac; F0fdf: if (!(false === empty($redirectionVhostTemplate))) { goto cd0f2; } goto a16b6; f2276: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto e147e; a4f9d: E1dce: goto B7165; Cf0ac: $vhostTemplate->resetProcessors(); goto f6cbf; d3a8e: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Faa0a; f71d2: $constraintViolationList->addAll($pythonSettingsConstraints); goto aa607; ad873: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto a9a7e; ccb27: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto F0fdf; Dcd15: $csr = $csrGenerator->generate(); goto F456e; ae4b0: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto fb241; } goto fcc7b; D3207: $siteEntity->setCertificate($certificateEntity); goto defd3; B4ecd: $pythonSite->setPythonSettings($pythonSettingsEntity); goto d51d2; e7ec6: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto D4e28; f8f98: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto b445b; Faa0a: $certificateEntity->setCsr($csr); goto E1f81; e0b0e: $vhostTemplate->build(); goto bc1d7; bc1d7: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto caf0a; Ed5cf: $siteEntity->setPythonSettings($pythonSettingsEntity); goto F8bd9; b46a4: $certificateEntity = $this->certificateEntityManager->createEntity(); goto B79f3; f885c: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto e81f0; d5928: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto f0116; ee90e: fb241: goto F3519; f6cbf: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ad873; Ce3d0: $siteEntity->setUserPassword($siteUserPassword); goto db52c; ae9ae: $pythonSite->setSubdomain($subdomain); goto b3072; defd3: $pythonSite = new PythonSite(); goto a799a; Fac6d: throw new \Exception(implode("\73\x20", $errorMessages)); goto db2e7; D3adc: $siteEntity->setUser($siteUser); goto Ce3d0; e9035: $pythonSiteCreator->createLogrotateFile(); goto Ebc44; ad073: $constraintViolationList = new ConstraintViolationList(); goto Ee316; db52c: $siteEntity->setRootDirectory($domainName); goto ae4b0; C895f: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto ecf57; B6e9a: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto eee21; } goto Cad30; d05ca: $vhostTemplate->build(); goto bb839; fe55c: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Df975; f1b01: $siteEntity = $this->siteEntityManager->createEntity(); goto f0248; d2491: $subjectAlternativeNames[] = sprintf("\x77\167\x77\x2e\45\x73", $domainName); goto F91f3; db8f4: eee21: goto b3385; eead1: $certificateEntity->setSite($siteEntity); goto f33a3; ed246: $staticSiteCreator->createNginxVhost(); goto a5998; ecf57: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F76bb; C931f: $staticSite->setSubdomain($subdomain); goto f4a57; a6312: $siteConstraints = $this->validator->validate($siteEntity); goto Dad63; Cf670: $vhostTemplate->resetProcessors(); goto E7dad; C084b: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto ff9cf; bbeb2: $constraintViolationList = new ConstraintViolationList(); goto E0c92; a4cd5: $staticSite->setCertificate($certificateEntity); goto C084b; B040d: C223d: goto C0178; a5998: $staticSiteCreator->reloadNginxService(); goto f7f4e; a70e2: $subjectAlternativeNames = []; goto b485d; e2918: $staticSite->setDomainName($domainName); goto Fafdf; f0bfb: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Dfad9; f4a57: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto a4cd5; b485d: if (!(true === is_null($subdomain))) { goto Caddc; } goto d2491; C53e3: b8fdd: goto E0a8b; E8d9c: $siteEntity->setUser($siteUser); goto b98e1; B2b77: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto f1b01; df4f3: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Cf670; Cad30: $subjectAlternativeNames[] = $registrableDomain; goto db8f4; d425c: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto B040d; A5c1b: if (!(false === empty($redirectionVhostTemplate))) { goto C223d; } goto d425c; A3cbd: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto F0e4d; a023b: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto ff259; } goto A17e3; c5fa1: $siteEntity->setVhostTemplate($vhostTemplate); goto a6312; D8020: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto A5c1b; De143: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto a70e2; Dad63: if (!count($siteConstraints)) { goto b8fdd; } goto bbeb2; f7825: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto B2b77; E7dad: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto d0ed0; D0c5d: $siteEntity->setDomainName($domainName); goto E8d9c; Df975: $certificateEntity->setDefaultCertificate(true); goto B6c1e; D6024: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto a477d; F1112: $certificateEntity->setCsr($csr); goto f0bfb; E63fa: throw new \Exception(implode("\73\x20", $errorMessages)); goto C53e3; c87c0: $staticSite->setUser($siteEntity->getUser()); goto bd46e; E0a8b: $certificateEntity = $this->certificateEntityManager->createEntity(); goto eead1; Fafdf: $staticSite->setRegistrableDomain($registrableDomain); goto C931f; F4948: $staticSite = new StaticSite(); goto c87c0; f33a3: $rsaKeyGenerator = new RsaKeyGenerator(); goto De143; bb839: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto A3cbd; b3385: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto D6024; b98e1: $siteEntity->setUserPassword($siteUserPassword); goto ffaa4; B6c1e: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto F1112; Fe739: $staticSiteCreator->createLogrotateFile(); goto Ee974; Dfad9: $certificateEntity->setCertificate($selfSignedCertificate); goto C3bb0; F6b27: $staticSiteCreator->createPrivateKeyAndCertificate(); goto ed246; a477d: $csr = $csrGenerator->generate(); goto fe55c; bd46e: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto e2918; ff9cf: $staticSiteCreator = new StaticSiteCreator($staticSite); goto d47f1; B5096: return $siteEntity; goto A1e24; F76bb: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto cf82f; f0248: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto D0c5d; d81b9: $vhostTemplate = new StaticVhostTemplate($staticSite); goto df4f3; f7f4e: $staticSiteCreator->resetPermissions(); goto d81b9; Ee974: $staticSiteCreator->createIndexHtml(); goto F6b27; C0178: ff259: goto c5fa1; cf82f: $subdomain = $resolvedDomainName->subDomain()->toString(); goto D4670; F91f3: Caddc: goto B6e9a; e13b1: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto E63fa; C3c78: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto d05ca; c64d8: $staticSiteCreator->createRootDirectory(); goto Fe739; d0ed0: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto C3c78; A17e3: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\56\57\56\x2e\57\x72\145\x73\x6f\165\162\x63\x65\x73\57\156\147\x69\x6e\170\x2f\x76\150\157\163\164\x5f\164\x65\x6d\160\x6c\141\x74\x65\x2f\x72\x65\x64\151\162\145\x63\164"); goto D8020; ffaa4: $siteEntity->setRootDirectory($domainName); goto a023b; F0e4d: $this->siteEntityManager->updateEntity($siteEntity); goto B5096; C3bb0: $siteEntity->setCertificate($certificateEntity); goto F4948; d47f1: $staticSiteCreator->createUser(); goto c64d8; D4670: $subdomain = false === empty($subdomain) ? $subdomain : null; goto f7825; E0c92: $constraintViolationList->addAll($siteConstraints); goto e13b1; A1e24: } public function installedWordPressSite(Request $request) : Response { goto B0cc5; c2414: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto d7414; F2c6a: return $response; goto c6bcb; D5c17: c690f: goto c2414; Fbefd: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\151\x74\x65\163")); goto d8800; E691e: return $response; goto f26f4; B0cc5: $session = $request->getSession(); goto B79de; d7414: $response = $this->render("\106\162\x6f\156\164\x65\156\144\57\x53\x69\x74\x65\57\116\x65\x77\57\167\157\162\x64\160\162\145\163\x73\55\151\156\163\164\x61\x6c\154\x65\144\x2e\x68\x74\155\x6c\56\x74\167\151\147", ["\x73\x69\164\145\x43\x72\x65\144\x65\x6e\x74\x69\x61\x6c\x73" => $siteCredentials]); goto E691e; f26f4: f9a0f: goto F2c6a; B79de: $siteCredentials = $session->get("\x73\x69\x74\x65\103\x72\x65\144\145\156\x74\x69\141\x6c\163"); goto F206f; d8800: goto f9a0f; goto D5c17; F206f: if (false === empty($siteCredentials)) { goto c690f; } goto Fbefd; c6bcb: } private function renderSiteCredentials(array $siteCredentials) : string { goto ece15; ee6b4: e8cd6: goto a6eb6; a6eb6: return $renderedCredentials; goto C7e0d; ece15: $renderedCredentials = ''; goto cbe04; cbe04: foreach ($siteCredentials as $section => $sectionData) { goto f3f9a; Cb2df: B105b: goto Dda33; Dda33: $renderedCredentials .= PHP_EOL; goto Cf686; Cf686: f3f3d: goto fe6d1; f3f9a: $renderedCredentials .= $section . PHP_EOL; goto bf87c; fc7b6: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\163\72\x20\45\163", $key, $value) . PHP_EOL; dd70c: } goto Cb2df; bf87c: $renderedCredentials .= "\x2d\x2d\55\x2d\55\55\55\55\x2d\55\x2d\x2d\55\x2d\55\55\x2d\55\55\55\x2d\55\55\x2d\x2d\55\55\55\x2d\x2d\x2d\x2d\x2d\x2d\55\55\55\x2d\55\x2d\55\x2d\55\55\x2d\55\x2d\55\x2d\x2d\55\x2d\55\55" . PHP_EOL; goto fc7b6; fe6d1: } goto ee6b4; C7e0d: } private function getVhostTemplateEntity(string $name) : mixed { goto F8cc5; D8e7f: return $vhostTemplateEntity; goto Cf707; a414e: f801d: goto D8e7f; F4aef: throw new \Exception($this->translator->trans("\x56\x68\x6f\x73\x74\40\124\145\155\x70\x6c\x61\164\x65\40\x25\x76\x68\157\163\x74\124\145\155\x70\x6c\141\164\145\45\x20\x64\x6f\x65\x73\x20\156\157\164\x20\x65\170\x69\x73\x74\x2e", ["\x25\x76\150\157\163\164\x54\145\155\160\154\141\164\145\45" => $name])); goto a414e; F8cc5: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto dbf9e; dbf9e: if (!(true === is_null($vhostTemplateEntity))) { goto f801d; } goto F4aef; Cf707: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto Ec59a; E60ca: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\x73\x3a\x20\x25\163", $constraint->getPropertyPath(), $constraint->getMessage()); E061b: } goto c68cf; Ec59a: $errorMessages = []; goto E60ca; c68cf: E98f1: goto Eecae; Eecae: return $errorMessages; goto faacf; faacf: } private function generateNameFromDomainName(string $domainName) : string { goto e5793; ad463: $name = $explodedRegistrableDomain[0] ?? ''; goto A7736; e5793: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Bb15f; Bb15f: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto c952b; A7736: F3b44: goto bd97c; c952b: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Fb2ba; Fb2ba: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto D46c1; f1010: goto F3b44; goto B25fe; F51cc: $name = $explodedRegistrableDomain[0] ?? ''; goto Ee66f; Ee66f: if (!(false === empty($subdomain))) { goto b536b; } goto B9439; B25fe: e1ccd: goto ad463; B9439: $name = sprintf("\45\x73\55\45\x73", $explodedRegistrableDomain[0] ?? '', $subdomain); goto Bc69b; Bc69b: b536b: goto f1010; bd97c: return $name; goto D19a4; D46c1: if ("\167\x77\x77" == $subdomain) { goto e1ccd; } goto F51cc; D19a4: } private function getUniqueSiteUserName(string $siteUser) : string { goto cfb31; d76ea: Ca3b1: goto Cd144; b1d58: if (false === is_null($siteEntity)) { goto Ca3b1; } goto e71bf; ca76a: $i++; goto b1d58; Cd144: if (!(0 < $i)) { goto c8e62; } goto ef45b; C0c0e: if (!(strlen($uniqueSiteUserName) <= 3)) { goto A0861; } goto D981f; cfb31: $uniqueSiteUserName = $siteUser; goto C0c0e; D981f: $uniqueSiteUserName = sprintf("\45\x73\55\x73\x69\164\x65", $uniqueSiteUserName); goto Ac88f; e71bf: a593b: goto E59f1; Ac88f: A0861: goto d8df5; B5f14: $siteEntity = $this->siteEntityManager->findOneByUser($uniqueSiteUserName); goto ca76a; d5379: c8e62: goto B5f14; E59f1: return $uniqueSiteUserName; goto D389e; ef45b: $uniqueSiteUserName = sprintf("\x25\x73\x2d\x25\x73", $siteUser, $i); goto d5379; d8df5: $i = 0; goto d76ea; D389e: } private function getUniqueDatabaseName(string $databaseName) : string { goto Ae9c8; Fa7c2: if (true === $databaseExists) { goto F086f; } goto C8fb9; eb756: $i = 0; goto b26f9; B5841: $i++; goto Fa7c2; e1eab: Ec56d: goto a129e; d7378: d4c50: goto eb756; Addf0: $uniqueDatabaseName = sprintf("\45\x73\x2d\x25\163", $databaseName, $i); goto e1eab; Bfb39: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto e6d50; a129e: $databaseExists = in_array($uniqueDatabaseName, $databases); goto B5841; ce9f7: F086f: goto Ff543; b26f9: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Bfb39; Cd2c1: if (!(strlen($uniqueDatabaseName) <= 3)) { goto d4c50; } goto Fdcaa; Ae9c8: $uniqueDatabaseName = $databaseName; goto Cd2c1; a7d6a: return $uniqueDatabaseName; goto c183d; e6d50: $databases = $databaseConnection->getDatabases(); goto ce9f7; C8fb9: bc39e: goto a7d6a; Fdcaa: $uniqueDatabaseName = sprintf("\45\163\x2d\144\x62", $uniqueDatabaseName); goto d7378; Ff543: if (!(0 < $i)) { goto Ec56d; } goto Addf0; c183d: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto cd111; a19bd: if (false === is_null($databaseUserEntity)) { goto C87e7; } goto Bfcc6; Fd1ae: $uniqueDatabaseUserName = sprintf("\x25\163\55\144\142", $uniqueDatabaseUserName); goto A5eca; cd111: $uniqueDatabaseUserName = $databaseUserName; goto d459d; fb535: C87e7: goto c3306; Fb04f: $i++; goto a19bd; Ee828: $i = 0; goto fb535; b32ec: $uniqueDatabaseUserName = sprintf("\45\x73\55\45\x73", $databaseUserName, $i); goto d8308; A5eca: f9097: goto Ee828; b1ad8: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto Fb04f; c3306: if (!(0 < $i)) { goto e9214; } goto b32ec; d459d: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto f9097; } goto Fd1ae; a79b2: return $uniqueDatabaseUserName; goto e03db; d8308: e9214: goto b1ad8; Bfcc6: c51d9: goto a79b2; e03db: } private function hasPermissions() : bool { goto d4e53; Aa350: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto F61a7; } goto Eb135; d272d: F61a7: goto a3dcf; d4e53: $user = $this->getUser(); goto Aa350; a3dcf: return false; goto E6909; Eb135: return true; goto d272d; E6909: } }
